==> cueplot-0.0.1-src.tar.gz: cueplot-0.0.1-src/gui/opt/TerminalOptionWidget.h <==
/*
 * Cueplot: a GUI front end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef TERMINAL_OPTION_WIDGET_INCLUDED
#define TERMINAL_OPTION_WIDGET_INCLUDED

#include "OptionWidget.h"

class Terminal;

#include <QBitArray>
class QComboBox;
class QPushButton;
class QStackedWidget;

class TerminalOptionWidget : public OptionWidget
{
	Q_OBJECT

	public:
		TerminalOptionWidget(QWidget *parent = 0);

		void construct();

	private slots:
		void initOption();
		void changeTerminal(int index);

	private:
		// don't implement these
		TerminalOptionWidget(const TerminalOptionWidget &);
		TerminalOptionWidget &operator=(const TerminalOptionWidget &);

		void init();
		void apply();
		bool hasOption(const QString &type);
		static const QString TERMINAL[];
		QComboBox *typeComboBox;
		QStackedWidget *typeStackedWidget;
		QPushButton *initPushButton;
		QBitArray initBitArray;
};
#endif // TERMINAL_OPTION_WIDGET_INCLUDED

==> cueplot-0.0.2-src.tar.gz: cueplot-0.0.2-src/gui/opt/TerminalOptionWidget.h <==
/*
 * Cueplot: a GUI front end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef TERMINAL_OPTION_WIDGET_INCLUDED
#define TERMINAL_OPTION_WIDGET_INCLUDED

#include "OptionWidget.h"

class Terminal;

#include <QBitArray>
class QComboBox;
class QPushButton;
class QStackedWidget;

class TerminalOptionWidget : public OptionWidget
{
	Q_OBJECT

	public:
		TerminalOptionWidget(QWidget *parent = 0);
		~TerminalOptionWidget();

		void construct();

	private slots:
		void initOption();
		void changeTerminal(int index);

	private:
		// don't implement these
		TerminalOptionWidget(const TerminalOptionWidget &);
		TerminalOptionWidget &operator=(const TerminalOptionWidget &);

		void init();
		void apply();
		void setWidget();
		bool hasOption(const QString &type);
		static const QString TERMINAL[];
		static const QString TERMINAL_WITH_OPTION[];
		Terminal *terminal;
		QComboBox *typeComboBox;
		QStackedWidget *typeStackedWidget;
		QPushButton *initPushButton;
		QBitArray initBitArray;
};
#endif // TERMINAL_OPTION_WIDGET_INCLUDED
